@@ -102,7 +102,7 @@ predict(modc, newdata=learn)[1:10]
 # bundling for survival
 
 data(GBSG2)
-rcomb <- list(list(model=coxph, predict=predict.coxph))
+rcomb <- list(list(model=coxph, predict=predict))
 
 mods <- bagging(Surv(time,cens) ~ ., data=GBSG2, nbagg=10, 
                 comb=rcomb,  control=rpart.control(xval=0))
